==> scotch-7.0.11-1-x86_64.pkg.tar.zst: usr/lib/cmake/scotch/SCOTCHConfig.cmake <==
## Copyright 2014-2016,2021-2023,2025 IPB, Universite de Bordeaux, INRIA & CNRS
##
## This file is part of the Scotch software package for static mapping,
## graph partitioning and sparse matrix ordering.
##
## This software is governed by the CeCILL-C license under French law
## and abiding by the rules of distribution of free software. You can
## use, modify and/or redistribute the software under the terms of the
## CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
## URL: "http://www.cecill.info".
##
## As a counterpart to the access to the source code and rights to copy,
## modify and redistribute granted by the license, users are provided
## only with a limited warranty and the software's author, the holder of
## the economic rights, and the successive licensors have only limited
## liability.
##
## In this respect, the user's attention is drawn to the risks associated
## with loading, using, modifying and/or developing or reproducing the
## software by the user in light of its specific status of free software,
## that may mean that it is complicated to manipulate, and that also
## therefore means that it is reserved for developers and experienced
## professionals having in-depth computer knowledge. Users are therefore
## encouraged to load and test the software's suitability as regards
## their requirements in conditions enabling the security of their
## systems and/or data to be ensured and, more generally, to use and
## operate it in the same conditions as regards security.
##
## The fact that you are presently reading this means that you have had
## knowledge of the CeCILL-C license and that you accept its terms.
##
############################################################
##                                                        ##
##   AUTHORS    : Marc FUENTES                            ##
##                Florent PRUVOST                         ##
##                Cedric LACHAT                           ##
##                Amaury JACQUES                          ##
##                Xavier MULLER                           ##
##                                                        ##
##   FUNCTION   : Secondary configuration file for CMake  ##
##                                                        ##
##   DATES      : # Version 6.0  : from : 01 sep 2014     ##
##                                 to     01 sep 2021     ##
##                # Version 7.0  : from : 01 sep 2021     ##
##                                 to     08 jul 2025     ##
##                                                        ##
############################################################

set(SCOTCH_VERSION 7.0.11)

# Relocatable package

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was SCOTCHConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/scotch" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set_and_check(SCOTCH_INCLUDE_DIR "${PACKAGE_PREFIX_DIR}/include")
set_and_check(SCOTCH_LIBRARY_DIR "${PACKAGE_PREFIX_DIR}/lib")

# Manage dependencies
include(CMakeFindDependencyMacro)
find_dependency(Threads)
if(ON)
  find_dependency(MPI REQUIRED)
endif()

# Add target files
include("${CMAKE_CURRENT_LIST_DIR}/scotcherrexitTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/scotcherrTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/scotchTargets.cmake")
if(ON)
  set(SCOTCH_PTSCOTCH_FOUND ON)
  include("${CMAKE_CURRENT_LIST_DIR}/ptscotcherrexitTargets.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/ptscotcherrTargets.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/ptscotchTargets.cmake")
endif()
if(ON)
  set(SCOTCH_LIBESMUMPS_FOUND ON)
  include("${CMAKE_CURRENT_LIST_DIR}/esmumpsTargets.cmake")
  if(ON)
    set(SCOTCH_LIBPTESMUMPS_FOUND ON)
    include("${CMAKE_CURRENT_LIST_DIR}/ptesmumpsTargets.cmake")
  endif()
endif()
if(ON)
  if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/scotchmetisTargets.cmake")
    set(SCOTCH_LIBSCOTCH_METIS_FOUND ON)
    include("${CMAKE_CURRENT_LIST_DIR}/scotchmetisTargets.cmake")
  endif()
  if(ON)
    if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/ptscotchparmetisTargets.cmake")
      set(SCOTCH_LIBSCOTCH_PARMETIS_FOUND ON)
      include("${CMAKE_CURRENT_LIST_DIR}/ptscotchparmetisTargets.cmake")
    endif()
  endif()
endif()

check_required_components(SCOTCH)

==> scotch-7.0.11-3-x86_64.pkg.tar.zst: usr/lib/cmake/scotch/SCOTCHConfig.cmake <==
## Copyright 2014-2016,2021-2023,2025 IPB, Universite de Bordeaux, INRIA & CNRS
##
## This file is part of the Scotch software package for static mapping,
## graph partitioning and sparse matrix ordering.
##
## This software is governed by the CeCILL-C license under French law
## and abiding by the rules of distribution of free software. You can
## use, modify and/or redistribute the software under the terms of the
## CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
## URL: "http://www.cecill.info".
##
## As a counterpart to the access to the source code and rights to copy,
## modify and redistribute granted by the license, users are provided
## only with a limited warranty and the software's author, the holder of
## the economic rights, and the successive licensors have only limited
## liability.
##
## In this respect, the user's attention is drawn to the risks associated
## with loading, using, modifying and/or developing or reproducing the
## software by the user in light of its specific status of free software,
## that may mean that it is complicated to manipulate, and that also
## therefore means that it is reserved for developers and experienced
## professionals having in-depth computer knowledge. Users are therefore
## encouraged to load and test the software's suitability as regards
## their requirements in conditions enabling the security of their
## systems and/or data to be ensured and, more generally, to use and
## operate it in the same conditions as regards security.
##
## The fact that you are presently reading this means that you have had
## knowledge of the CeCILL-C license and that you accept its terms.
##
############################################################
##                                                        ##
##   AUTHORS    : Marc FUENTES                            ##
##                Florent PRUVOST                         ##
##                Cedric LACHAT                           ##
##                Amaury JACQUES                          ##
##                Xavier MULLER                           ##
##                                                        ##
##   FUNCTION   : Secondary configuration file for CMake  ##
##                                                        ##
##   DATES      : # Version 6.0  : from : 01 sep 2014     ##
##                                 to     01 sep 2021     ##
##                # Version 7.0  : from : 01 sep 2021     ##
##                                 to     08 jul 2025     ##
##                                                        ##
############################################################

set(SCOTCH_VERSION 7.0.11)

# Relocatable package

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was SCOTCHConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/scotch" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set_and_check(SCOTCH_INCLUDE_DIR "${PACKAGE_PREFIX_DIR}/include/scotch")
set_and_check(SCOTCH_LIBRARY_DIR "${PACKAGE_PREFIX_DIR}/lib")

# Manage dependencies
include(CMakeFindDependencyMacro)
find_dependency(Threads)
if(ON)
  find_dependency(MPI REQUIRED)
endif()

# Add target files
include("${CMAKE_CURRENT_LIST_DIR}/scotcherrexitTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/scotcherrTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/scotchTargets.cmake")
if(ON)
  set(SCOTCH_PTSCOTCH_FOUND ON)
  include("${CMAKE_CURRENT_LIST_DIR}/ptscotcherrexitTargets.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/ptscotcherrTargets.cmake")
  include("${CMAKE_CURRENT_LIST_DIR}/ptscotchTargets.cmake")
endif()
if(ON)
  set(SCOTCH_LIBESMUMPS_FOUND ON)
  include("${CMAKE_CURRENT_LIST_DIR}/esmumpsTargets.cmake")
  if(ON)
    set(SCOTCH_LIBPTESMUMPS_FOUND ON)
    include("${CMAKE_CURRENT_LIST_DIR}/ptesmumpsTargets.cmake")
  endif()
endif()
if(ON)
  if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/scotchmetisTargets.cmake")
    set(SCOTCH_LIBSCOTCH_METIS_FOUND ON)
    include("${CMAKE_CURRENT_LIST_DIR}/scotchmetisTargets.cmake")
  endif()
  if(ON)
    if(EXISTS "${CMAKE_CURRENT_LIST_DIR}/ptscotchparmetisTargets.cmake")
      set(SCOTCH_LIBSCOTCH_PARMETIS_FOUND ON)
      include("${CMAKE_CURRENT_LIST_DIR}/ptscotchparmetisTargets.cmake")
    endif()
  endif()
endif()

check_required_components(SCOTCH)
